@@ -1,7 +1,9 @@
 package WebService::GData::Error::Entry;
 use WebService::GData;
 use base 'WebService::GData';
-our $VERSION  = 0.01_01;
+
+our $VERSION  = 0.01_02;
+
 WebService::GData::install_in_package([qw(internalreason domain code location)],
 	sub {
 		my $func=shift;
@@ -42,7 +44,7 @@ WebService::GData::install_in_package([qw(internalreason domain code location)],
 		   $xml.='<internalreason>'.$this->internalreason.'</internalreason>' if($this->internalreason);
 		   $xml.='<code>'.$this->code.'</code>' if($this->code);
 		   $xml.='<domain>'.$this->domain.'</domain>' if($this->domain);	
-		   $xml.="<location type='".$this->location->{type}.'>'.$this->location->{content}.'</location>' if($this->location);
+		   $xml.="<location type='".$this->location->{type}."'>".$this->location->{content}.'</location>' if($this->location);
 	       $xml.='</error>';
 		return $xml;
 	}
@@ -55,11 +57,8 @@ __END__
 
 =head1 NAME
 
-WebService::GData::Error::Entry - wrap an xml error sent back by Google data APIs v2.
+WebService::GData::Error::Entry - Wrap an xml error sent back by Google data APIs v2.
 
-=head1 VERSION
-
-0.01
 
 =head1 SYNOPSIS
 
@@ -78,70 +77,189 @@ WebService::GData::Error::Entry - wrap an xml error sent back by Google data API
 	$entry->code('too_long');
 	$entry->domain('your_domain');
 	$entry->location({type=>'header',content=>'Missing Version header'});
-	print $entry->serialize()#return <error>...</error> entry
+	print $entry->serialize()#return <error>...</error> 
 
 
 
 
 =head1 DESCRIPTION
 
-inherits from WebService::GData;
+I<inherits from L<WebService::GData>>
 
 This package can parse error response from Google APIs service. You can also create your own basic xml error.
 
 All WebService::GData::* classes die a WebService::GData::Error object when something went wrong.
 
-You should use an eval {}; block to catch the error.
+XML error Example:
+
+    <error>
+         <domain>yt:validation</domain>
+         <code>invalid_character</code>
+         <location type='xpath'>media:group/media:title/text()</location>
+    </error>
 
 Example:
 
-	use WebService::GData::Error;
+    use WebService::GData::Error;
 
     #parse an error from a Google data API server...
-   	my $entry = new WebService::GData::Error::Entry($xmlerror);
-	$entry->code;
-	$entry->internalreason;
-	$entry->domain;
-	$entry->location->{type};#this is just a hash
-	$entry->location->{content};#this is just a hash
+    my $entry = new WebService::GData::Error::Entry($xmlerror);
+    $entry->code;
+    $entry->internalreason;
+    $entry->domain;
+    $entry->location->{type};#this is just a hash
+    $entry->location->{content};#this is just a hash
 
     #create an error from a Google data API server...
-   	my $entry = new WebService::GData::Error::Entry();
-	$entry->code('too_long');
-	$entry->domain('your_domain');
-	$entry->location({type=>'header',content=>'Missing Version header'});
+    my $entry = new WebService::GData::Error::Entry();
+    $entry->code('too_long');
+    $entry->domain('your_domain');
+    $entry->location({type=>'header',content=>'Missing Version header'});
 
 
 
-=head1 METHODS
+=head2 Constructor
 
-=head2 new (content:Scalar)
+=head3 new 
+
+Create a L<WebService::GData::Error::Entry> instance.
+
+If the content is an xml following the Google data API format, it will get parse.
+
+
+I<Parameters>:
 
 =over
 
-=head2 code
+=item C<content:Scalar>(optional)
+
+=back
+
+I<Return>:
 
 =over
 
+=item L<WebService::GData::Error::Entry>
+
+=back
+
+=head2 GET/SET METHODS
+
+These methods return their content if no parameters is passed or set their content if a parameter is set.
+
+
+=head3 code
+
 Get/set an error code.
 
-=head2 location
+I<Parameters>:
 
 =over
 
+=item none
+
+Work as a getter
+
+=item C<content:Scalar>
+
+Work as a setter
+
+=back
+
+I<Return>:
+
+=over
+
+=item C<content:Scalar>
+
+When use as a getter
+
+=back
+
+=head3 location
+
 Get/set the error location as an xpath.
 
 It requires an hash with type and content as keys.
 
-=head2 domain
+I<Parameters>:
 
 =over
 
+=item none
+
+Work as a getter
+
+=item C<content:HashRef>
+
+Work as a setter. the hash must be in contain the following : {type=>'...',content=>'...'}.
+
+=back
+
+I<Return>:
+
+=over
+
+=item C<content:HashRef>
+
+When use as a getter
+
+=back
+
+=head3 domain
+
 Get/set the type of error. Google data API has validation,quota,authentication,service errors.
 
-=head1 SEE ALSO
+I<Parameters>:
 
-Format of the errors, kind of errors and details:
+=over
+
+=item none
+
+Work as a getter
+
+=item C<content:Scalar>
+
+Work as a setter. 
+
+=back
+
+I<Return>:
+
+=over
+
+=item C<content:Scalar>
+
+When use as a getter
+
+=back
+
+=head3 serialize
+
+Send back an xml representation of an error.
+
+I<Parameters>:
+
+=over
+
+=item none
+
+=back
+
+I<Return>:
+
+=over
+
+=item C<content:Scalar>
+
+Where the content is an xml representation of the error.
+
+=back
+
+
+=head2 SEE ALSO
+
+Format of the xml and explanation of the different kind of errors you can encounter:
 
 L<http://code.google.com/intl/en/apis/youtube/2.0/developers_guide_protocol_error_responses.html>
 
@@ -152,9 +270,7 @@ none
 
 =head1  DEPENDENCIES
 
-L<JSON>
-
-L<LWP>
+none
 
 =head1  INCOMPATIBILITIES
 
@@ -167,7 +283,7 @@ i will try to do my best to fix it (patches welcome)!
 
 =head1 AUTHOR
 
-shiriru E<lt>shiriru0111[arobas]hotmail.comE<gt>
+shiriru E<lt>shirirulestheworld[arobas]gmail.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
